@@ -25,7 +25,7 @@ using namespace KHC;
 Application::Application(int& argc, char** argv)
     : QApplication(argc, argv), mMainWindow( nullptr )
 {
-  setAttribute(Qt::AA_UseHighDpiPixmaps);
+  KLocalizedString::setApplicationDomain("khelpcenter5");
 
   mCmdParser.addPositionalArgument( QStringLiteral("url"), i18n( "Documentation to open" ) );
 
@@ -109,8 +109,8 @@ void Application::open(const QList<QUrl>& urls)
 
 int main( int argc, char **argv )
 {
+  QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
   KHC::Application app(argc, argv);
-  KLocalizedString::setApplicationDomain("khelpcenter5");
   KAboutData aboutData( QStringLiteral("khelpcenter"), i18n("Help Center"),
                         QStringLiteral(PROJECT_VERSION),
                         i18n("Help Center"),
