@@ -1,23 +1,9 @@
- /*
- *  This file is part of the KDE Help Center
- *
- *  Copyright (C) 1999 Matthias Elter (me@kde.org)
- *                2001 Stephan Kulow (coolo@kde.org)
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 1999 Matthias Elter <me@kde.org>
+    SPDX-FileCopyrightText: 2001 Stephan Kulow <coolo@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "mainwindow.h"
 
@@ -37,6 +23,7 @@
 #include <QDir>
 #include <QIcon>
 #include <QList>
+#include <QMenuBar>
 #include <QMimeDatabase>
 #include <QPushButton>
 #include <QSplitter>
@@ -55,16 +42,11 @@
 #include <KHTMLView>
 #include <KStandardAction>
 #include <KStartupInfo>
+#include <KToolBar>
 #include <KWindowConfig>
 
-#include <kio_version.h>
-#if KIO_VERSION < QT_VERSION_CHECK(5, 71, 0)
-#include <KRun>
-#else
 #include <KIO/JobUiDelegate>
 #include <KIO/OpenUrlJob>
-#endif
-
 #include <KIO/Job>
 
 #include <prefs.h>
@@ -234,6 +216,8 @@ void MainWindow::setupActions()
     nextPage->setWhatsThis( i18n( "Moves to the next page of the document" ) );
     connect( nextPage, &QAction::triggered, mDoc, &View::nextPage );
 
+    KStandardAction::fullScreen( this, SLOT( slotFullScreen() ), this, actionCollection() );
+
     QAction *home = KStandardAction::home( this, SLOT(slotShowHome()), this );
     actionCollection()->addAction( home->objectName(), home );
     home->setText(i18n("Table of &Contents"));
@@ -288,7 +272,8 @@ void MainWindow::setupBookmarks()
     connect( owner, &BookmarkOwner::openUrl, this, QOverload<const QUrl &>::of(&MainWindow::openUrl) );
     KActionMenu *actmenu = actionCollection()->add<KActionMenu>( QStringLiteral( "bookmarks" ) );
     actmenu->setText( i18nc( "@title:menu", "&Bookmarks" ) );
-    KBookmarkMenu *bookmenu = new KBookmarkMenu( manager, owner, actmenu->menu(), actionCollection() );
+    auto *bookmenu = new KBookmarkMenu( manager, owner, actmenu->menu());
+    actionCollection()->addActions(actmenu->menu()->actions());
     bookmenu->setParent( owner );
 }
 
@@ -361,13 +346,9 @@ void MainWindow::viewUrl( const QUrl &url, const KParts::OpenUrlArguments &args,
     }
 
     if ( !own ) {
-#if KIO_VERSION < QT_VERSION_CHECK(5, 71, 0)
-        new KRun( url,this );
-#else
         auto *job = new KIO::OpenUrlJob(QUrl(url));
         job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
         job->start();
-#endif
         return;
     }
 
@@ -518,5 +499,16 @@ void MainWindow::slotConfigureFonts()
   }
 }
 
+void MainWindow::slotFullScreen()
+{
+  if (!mFullScreen) {
+    KToggleFullScreenAction::setFullScreen(this, true);
+    mFullScreen = true;
+  } else {
+    KToggleFullScreenAction::setFullScreen(this, false);
+    mFullScreen = false;
+  }
+}
+
 
 // vim:ts=2:sw=2:et
