@@ -1,23 +1,9 @@
- /*
- *  This file is part of the KDE Help Center
- *
- *  Copyright (C) 1999 Matthias Elter (me@kde.org)
- *                2001 Stephan Kulow (coolo@kde.org)
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 1999 Matthias Elter <me@kde.org>
+    SPDX-FileCopyrightText: 2001 Stephan Kulow <coolo@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef KHC_MAINWINDOW_H
 #define KHC_MAINWINDOW_H
@@ -63,6 +49,7 @@ class MainWindow : public KXmlGuiWindow
     void statusBarMessage(const QString &m);
     void slotShowHome();
     void slotLastSearch();
+    void slotFullScreen();
     void showSearchStderr();
     /**
       Show document corresponding to given URL in viewer part.
@@ -125,6 +112,7 @@ private:
     QAction *mLastSearchAction = nullptr;
     QAction *mCopyText = nullptr;
     LogDialog *mLogDialog = nullptr;
+    bool mFullScreen = false;
 };
 
 }
